Page 66 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 66

Home

    In 1760 King George III came along and set out to
    control every detail affecting the lives of his subjects at
    home and abroad. The first thing he did was restrict
    emigration to the colonies and prohibit any more settlers
    from moving westward. The King's planning even
    included American trees, with the King's men going
    through the forest and marking the best pine to be held
    for the royal navy.

    This so irritated the colonists that they not only went
    out of their way to use the marked trees, they also
    adopted the pine tree as their symbol of liberty.
    Whenever the British government tried to place
    restrictions on trade, the colonists went right on trading.
    When the weaving of cloth was prohibited in the

    tried

    to

    colonies, the women went right on working at their
    looms, with the stage being set for a confrontation until
    finally, "the embattled farmers" stood at the Concord
    bridge and fired the "the shot heard ‘round the world."

    It is interesting to note, that in trying to manage a
    planned economy, the object of government regulations
    is always to prevent a fall in prices, just the opposite of
    what creates prosperity. What government has never
    learned is that lower prices, not higher prices, aid the
    economy. It is an unheeded lesson of history that
    government interference in the marketplace always

    e484 1 ¥.

    61

    The American Republic

    the King's navy, but this was just considered an ordinary

    business risk.

    works to harmful ends. It never helps.